@@ -4,11 +4,10 @@
 
 package Net::LDAP::Control::MatchedValues;
 
-use vars qw(@ISA $VERSION);
 use Net::LDAP::Control;
 
-@ISA = qw(Net::LDAP::Control);
-$VERSION = "0.01";
+our @ISA = qw(Net::LDAP::Control);
+our $VERSION = "0.02";
 
 use Net::LDAP::ASN qw(ValuesReturnFilter);
 use strict;
@@ -150,11 +149,10 @@ terms as Perl itself.
 
 package Net::LDAP::FilterList;
 
-use vars qw(@ISA $VERSION);
 use Net::LDAP::Filter;
 
-@ISA = qw(Net::LDAP::Filter);
-$VERSION = "0.02";
+our @ISA = qw(Net::LDAP::Filter);
+our $VERSION = "0.03";
 
 # filter       = "(" 1*item ")"
 # item         = simple / present / substring / extensible
@@ -174,7 +172,7 @@ $VERSION = "0.02";
 # attr         = AttributeDescription from Section 4.1.5 of [1]
 # matchingrule = MatchingRuleId from Section 4.1.9 of [1]
 # value        = AttributeValue from Section 4.1.6 of [1]
-# 
+#
 # Special Character encodings
 # ---------------------------
 #    *               \2a, \*
@@ -187,7 +185,7 @@ $VERSION = "0.02";
 sub new {
   my $self = shift;
   my $class = ref($self) || $self;
-  
+
   my $me = bless [], $class;
 
   if (@_) {
