@@ -3,8 +3,8 @@ package Net::LDAP::Extension::Cancel;
 
 require Net::LDAP::Extension;
 
-$VERSION = "0.01";
-@ISA = qw(Net::LDAP::Extension);
+our @ISA = qw(Net::LDAP::Extension);
+our $VERSION = "0.02";
 
 use Convert::ASN1;
 
