@@ -7,9 +7,8 @@ package Net::LDAP::Message;
 use Net::LDAP::Constant qw(LDAP_SUCCESS LDAP_COMPARE_TRUE LDAP_COMPARE_FALSE);
 use Net::LDAP::ASN qw(LDAPRequest);
 use strict;
-use vars qw($VERSION);
 
-$VERSION = "1.11";
+our $VERSION = "1.12";
 
 my $MsgID = 0;
 
@@ -149,7 +148,7 @@ sub decode { # $self, $pdu, $control
     my $intermediate = Net::LDAP::Intermediate->from_asn($data);
 
     if (defined $self->{callback}) {
-      $self->{callback}->($self, $intermediate)
+      $self->{callback}->($self, $intermediate);
     } else {
       push(@{$self->{'intermediate'} ||= []}, $intermediate);
     }
@@ -249,15 +248,16 @@ sub Net::LDAP::Compare::is_error {
 
 {
   package Net::LDAP::Message::Dummy;
-  use vars qw(@ISA);
-  @ISA = qw(Net::LDAP::Message);
+  our @ISA = qw(Net::LDAP::Message);
   use Net::LDAP::Constant qw(LDAP_SUCCESS);
 
   sub new {
     my $self   = shift;
     my $type   = ref($self) || $self;
 
-    $self = bless {}, $type;
+    $self = bless {
+      mesgid   => Net::LDAP::Message::NewMesgID(),
+    }, $type;
 
     $self;
   }
